"""
Aponyx - Systematic Macro Credit Strategy Framework.

A modular Python framework for developing and backtesting systematic credit strategies.
"""

from importlib.metadata import version

__version__ = version("aponyx")


def hello() -> str:
    """Return greeting message."""
    return "Hello from aponyx!"
